Installation
============

The latest tagged release can installed via pip:

::

    pip install aisim

Alternatively, if you plan to make changes to the code, use

::

    git clone https://github.com/bleykauf/aisim.git
    cd aisim
    python setup.py develop